============
Installation
============

For installation and usage of neutron-tempest-plugin, please refer
to the documentation in the Neutron tree:

    https://docs.openstack.org/neutron/latest/contributor/testing/tempest.html
